@@ -3,10 +3,10 @@ from os.path import join as pjoin
 
 # Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
 _version_major = 0
-_version_minor = 2
-_version_micro = 3  # use '' for first of series, number for 1 and above
-_version_extra = 'dev0'
-_version_extra = ''  # Uncomment this for full releases
+_version_minor = 3
+_version_micro = 6  # use '' for first of series, number for 1 and above
+_version_extra = "dev0"
+_version_extra = ""  # Uncomment this for full releases
 
 # Construct full version string from these.
 _ver = [_version_major, _version_minor]
@@ -15,15 +15,17 @@ if _version_micro:
 if _version_extra:
     _ver.append(_version_extra)
 
-__version__ = '.'.join(map(str, _ver))
+__version__ = ".".join(map(str, _ver))
 
-CLASSIFIERS = ["Development Status :: 3 - Alpha",
-               "Environment :: Console",
-               "Intended Audience :: Science/Research",
-               "License :: OSI Approved :: MIT License",
-               "Operating System :: OS Independent",
-               "Programming Language :: Python",
-               "Topic :: Scientific/Engineering"]
+CLASSIFIERS = [
+    "Development Status :: 3 - Alpha",
+    "Environment :: Console",
+    "Intended Audience :: Science/Research",
+    "License :: OSI Approved :: MIT License",
+    "Operating System :: OS Independent",
+    "Programming Language :: Python",
+    "Topic :: Scientific/Engineering",
+]
 
 # Description should be a one-liner:
 description = "nikamap: a package to manipulate data produced by the IDL NIKA2 pipeline"
@@ -67,7 +69,7 @@ MAJOR = _version_major
 MINOR = _version_minor
 MICRO = _version_micro
 VERSION = __version__
-PACKAGE_DATA = {'nikamap': [pjoin('data', '*')]}
-INSTALL_REQUIRES = ['numpy', 'scipy', 'matplotlib', 'astropy', 'photutils', 'scikit_image']
-SETUP_REQUIRES = ['pytest-runner']
-TESTS_REQUIRE = ['pytest', 'pytest-mpl']
+PACKAGE_DATA = {"nikamap": [pjoin("data", "*")]}
+INSTALL_REQUIRES = ["numpy", "scipy", "matplotlib", "astropy", "photutils", "scikit_image"]
+SETUP_REQUIRES = ["pytest-runner"]
+TESTS_REQUIRE = ["pytest", "pytest-mpl"]
